@@ -1593,11 +1593,8 @@ def init_diagonostic():
     # checking if the decrypted string is the same as the original
     print (decrypted_string)
     assert decrypted_string == b"Hello World"
-    # deleting all variables and test files
-    for i in globals():
-        del globals()[i]
-    for i in locals():
-        del locals()[i]
+    # deleting test file
+    os.remove("test_file.txt")
     print ("test complete; Fernet methods passed")
     print ("All tests completed | General functionality tests passed")
     print ("Beginning edge use case tests")
@@ -1615,6 +1612,7 @@ def init_diagonostic():
         pass
     except Exception as e:
         print (f"failure occurred during edge case test: {e}")
+    print ("All tests finished.")
     gc.collect()
     return 0
 
